@@ -58,7 +58,7 @@ class OAuth2:
     def __init__(self: object, base_url: str = "https://api.crowdstrike.com",
                  ssl_verify: bool = True, proxy: dict = None, timeout: float or tuple = None,
                  creds: dict = None, client_id: str = None, client_secret: str = None,
-                 user_agent: str = None):
+                 user_agent: str = None, member_cid: str = None):
         """Class constructor.
 
         Initializes the base class by ingesting credentials,
@@ -73,17 +73,23 @@ class OAuth2:
         creds -- Dictionary containing CrowdStrike API credentials.
                  Mutually exclusive to client_id / client_secret.
         client_id -- Client ID for the CrowdStrike API. Mutually exclusive to creds.
-        client_secret -- Client Secret for the CrowdStriek API. Mutually exclusive to creds.
+        client_secret -- Client Secret for the CrowdStrike API. Mutually exclusive to creds.
+        member_cid -- Child CID to connec to. Mutually exclusive to creds.
 
-        This method only accepts keywords to specify arguments.
+        This method only supports keywords to specify arguments.
         """
         if client_id and client_secret and not creds:
             creds = {
                 "client_id": client_id,
                 "client_secret": client_secret
             }
+            # Have to pass member_cid the same way you pass client_id / secret
+            # If you use a creds dictionary, pass the member_cid there instead
+            if member_cid:
+                creds["member_cid"] = member_cid
         elif not creds:
             creds = {}
+
         self.creds = creds
         self.base_url = confirm_base_url(base_url)
         self.ssl_verify = ssl_verify
@@ -120,10 +126,13 @@ class OAuth2:
                                        headers=header_payload, verify=self.ssl_verify,
                                        proxy=self.proxy, timeout=self.timeout,
                                        user_agent=self.user_agent)
-            if returned["status_code"] == 201:
-                self.token_expiration = returned["body"]["expires_in"]
-                self.token_time = time.time()
-                self.token_value = returned["body"]["access_token"]
+            if isinstance(returned, dict):  # Issue #433
+                if returned["status_code"] == 201:
+                    self.token_expiration = returned["body"]["expires_in"]
+                    self.token_time = time.time()
+                    self.token_value = returned["body"]["access_token"]
+            else:
+                returned = generate_error_result("Unexpected API response received", 403)
         else:
             returned = generate_error_result("Invalid credentials specified", 403)
 
@@ -155,3 +164,11 @@ class OAuth2:
             returned = generate_error_result("Invalid credentials specified", 403)
 
         return returned
+
+    # These method names align to the operation IDs in the API but
+    # do not conform to snake_case / PEP8 and are defined here for
+    # backwards compatibility / ease of use purposes
+    oauth2AccessToken = token
+    oAuth2AccessToken = token
+    oauth2RevokeToken = revoke
+    oAuth2RevokeToken = revoke
